@@ -46,7 +46,6 @@ typedef struct atomics_cobalt_parser_t atomics_cobalt_parser_t;
 struct atomics_cobalt_parser_t {
 	dc_parser_t base;
 	// Depth calibration.
-	double atmospheric;
 	double hydrostatic;
 };
 
@@ -82,7 +81,6 @@ atomics_cobalt_parser_create (dc_parser_t **out, dc_context_t *context)
 	}
 
 	// Set the default values.
-	parser->atmospheric = 0.0;
 	parser->hydrostatic = 1025.0 * GRAVITY;
 
 	*out = (dc_parser_t*) parser;
@@ -106,7 +104,6 @@ atomics_cobalt_parser_set_calibration (dc_parser_t *abstract, double atmospheric
 	if (!ISINSTANCE (abstract))
 		return DC_STATUS_INVALIDARGS;
 
-	parser->atmospheric = atmospheric;
 	parser->hydrostatic = hydrostatic;
 
 	return DC_STATUS_SUCCESS;
@@ -151,15 +148,10 @@ atomics_cobalt_parser_get_field (dc_parser_t *abstract, dc_field_type_t type, un
 	dc_gasmix_t *gasmix = (dc_gasmix_t *) value;
 	dc_tank_t *tank = (dc_tank_t *) value;
 
-	double atmospheric = 0.0;
+	unsigned int atmospheric = array_uint16_le (p + 0x26);
 	char buf[BUFLEN];
 	dc_field_string_t *string = (dc_field_string_t *) value;
 
-	if (parser->atmospheric)
-		atmospheric = parser->atmospheric;
-	else
-		atmospheric = array_uint16_le (p + 0x26) * BAR / 1000.0;
-
 	unsigned int workpressure = 0;
 
 	if (value) {
@@ -168,7 +160,7 @@ atomics_cobalt_parser_get_field (dc_parser_t *abstract, dc_field_type_t type, un
 			*((unsigned int *) value) = array_uint16_le (p + 0x58) * 60;
 			break;
 		case DC_FIELD_MAXDEPTH:
-			*((double *) value) = (array_uint16_le (p + 0x56) * BAR / 1000.0 - atmospheric) / parser->hydrostatic;
+			*((double *) value) = (signed int)(array_uint16_le (p + 0x56) - atmospheric) * (BAR / 1000.0) / parser->hydrostatic;
 			break;
 		case DC_FIELD_GASMIX_COUNT:
 		case DC_FIELD_TANK_COUNT:
@@ -220,6 +212,9 @@ atomics_cobalt_parser_get_field (dc_parser_t *abstract, dc_field_type_t type, un
 				return DC_STATUS_DATAFORMAT;
 			}
 			break;
+		case DC_FIELD_ATMOSPHERIC:
+			*((double *) value) = atmospheric / 1000.0;
+			break;
 		case DC_FIELD_STRING:
 			switch(flags) {
 			case 0: // Serialnr
@@ -274,11 +269,7 @@ atomics_cobalt_parser_samples_foreach (dc_parser_t *abstract, dc_sample_callback
 	if (size < header + SZ_SEGMENT * nsegments)
 		return DC_STATUS_DATAFORMAT;
 
-	double atmospheric = 0.0;
-	if (parser->atmospheric)
-		atmospheric = parser->atmospheric;
-	else
-		atmospheric = array_uint16_le (data + 0x26) * BAR / 1000.0;
+	unsigned int atmospheric = array_uint16_le (data + 0x26);
 
 	// Previous gas mix - initialize with impossible value
 	unsigned int gasmix_previous = 0xFFFFFFFF;
@@ -309,7 +300,7 @@ atomics_cobalt_parser_samples_foreach (dc_parser_t *abstract, dc_sample_callback
 
 		// Depth (1/1000 bar).
 		unsigned int depth = array_uint16_le (data + offset + 0);
-		sample.depth = (depth * BAR / 1000.0 - atmospheric) / parser->hydrostatic;
+		sample.depth = (signed int)(depth - atmospheric) * (BAR / 1000.0) / parser->hydrostatic;
 		if (callback) callback (DC_SAMPLE_DEPTH, sample, userdata);
 
 		// Pressure (1 psi).
