@@ -33,21 +33,22 @@
 #define MAXPARAMS 3
 #define NGASMIXES 11
 
-#define D9       0x0E
-#define D6       0x0F
-#define VYPER2   0x10
-#define COBRA2   0x11
-#define D4       0x12
-#define VYPERAIR 0x13
-#define COBRA3   0x14
-#define HELO2    0x15
-#define D4i      0x19
-#define D6i      0x1A
-#define D9tx     0x1B
-#define DX       0x1C
-#define VYPERNOVO 0x1D
-#define ZOOPNOVO  0x1E
-#define D4F       0x20
+#define D9          0x0E
+#define D6          0x0F
+#define VYPER2      0x10
+#define COBRA2      0x11
+#define D4          0x12
+#define VYPERAIR    0x13
+#define COBRA3      0x14
+#define HELO2       0x15
+#define D4i         0x19
+#define D6i         0x1A
+#define D9tx        0x1B
+#define DX          0x1C
+#define VYPERNOVO   0x1D
+#define ZOOPNOVO_A  0x1E
+#define ZOOPNOVO_B  0x1F
+#define D4F         0x20
 
 #define ID_D6I_V1_MIX2 0x1871C062
 #define ID_D6I_V1_MIX3 0x1871C063
@@ -144,8 +145,8 @@ suunto_d9_parser_cache (suunto_d9_parser_t *parser)
 		gasmode_offset = 0x1F;
 		gasmix_offset = 0x54;
 		gasmix_count = 8;
-	} else if (parser->model == D4i || parser->model == ZOOPNOVO ||
-		parser->model == D4F) {
+	} else if (parser->model == D4i || parser->model == ZOOPNOVO_A ||
+		parser->model == ZOOPNOVO_B || parser->model == D4F) {
 		gasmode_offset = 0x1D;
 		if (id == ID_D4I_V2)
 			gasmix_offset = 0x67;
@@ -182,8 +183,9 @@ suunto_d9_parser_cache (suunto_d9_parser_t *parser)
 		config += 1;
 	} else if (parser->model == HELO2 || parser->model == D4i ||
 		parser->model == D6i || parser->model == D9tx ||
-		parser->model == DX || parser->model == ZOOPNOVO ||
-		parser->model == VYPERNOVO || parser->model == D4F) {
+		parser->model == DX || parser->model == ZOOPNOVO_A ||
+		parser->model == ZOOPNOVO_B || parser->model == VYPERNOVO ||
+		parser->model == D4F) {
 		config = gasmix_offset + gasmix_count * 6;
 	}
 	if (config + 1 > size)
@@ -206,8 +208,9 @@ suunto_d9_parser_cache (suunto_d9_parser_t *parser)
 		for (unsigned int i = 0; i < gasmix_count; ++i) {
 			if (parser->model == HELO2 || parser->model == D4i ||
 				parser->model == D6i || parser->model == D9tx ||
-				parser->model == DX || parser->model == ZOOPNOVO ||
-				parser->model == VYPERNOVO || parser->model == D4F) {
+				parser->model == DX || parser->model == ZOOPNOVO_A ||
+				parser->model == ZOOPNOVO_B || parser->model == VYPERNOVO ||
+				parser->model == D4F) {
 				parser->oxygen[i] = data[gasmix_offset + 6 * i + 1];
 				parser->helium[i] = data[gasmix_offset + 6 * i + 2];
 			} else {
@@ -224,8 +227,9 @@ suunto_d9_parser_cache (suunto_d9_parser_t *parser)
 		if (parser->model == HELO2) {
 			parser->gasmix = data[0x26];
 		} else if (parser->model == D4i || parser->model == D6i ||
-			parser->model == D9tx || parser->model == ZOOPNOVO ||
-			parser->model == VYPERNOVO || parser->model == D4F) {
+			parser->model == D9tx || parser->model == ZOOPNOVO_A ||
+			parser->model == ZOOPNOVO_B || parser->model == VYPERNOVO ||
+			parser->model == D4F) {
 			if (id == ID_D4I_V2 || id == ID_D6I_V2) {
 				parser->gasmix = data[0x2D];
 			} else {
@@ -312,8 +316,9 @@ suunto_d9_parser_get_datetime (dc_parser_t *abstract, dc_datetime_t *datetime)
 	if (parser->model == HELO2 || parser->model == DX)
 		offset = 0x17;
 	else if (parser->model == D4i || parser->model == D6i ||
-		parser->model == D9tx || parser->model == ZOOPNOVO ||
-		parser->model == VYPERNOVO || parser->model == D4F)
+		parser->model == D9tx || parser->model == ZOOPNOVO_A ||
+		parser->model == ZOOPNOVO_B || parser->model == VYPERNOVO ||
+		parser->model == D4F)
 		offset = 0x13;
 
 	if (abstract->size < offset + 7)
@@ -324,8 +329,8 @@ suunto_d9_parser_get_datetime (dc_parser_t *abstract, dc_datetime_t *datetime)
 	if (datetime) {
 		if (parser->model == D4i || parser->model == D6i ||
 			parser->model == D9tx || parser->model == DX ||
-			parser->model == ZOOPNOVO || parser->model == VYPERNOVO ||
-			parser->model == D4F) {
+			parser->model == ZOOPNOVO_A || parser->model == ZOOPNOVO_B ||
+			parser->model == VYPERNOVO || parser->model == D4F) {
 			datetime->year   = p[0] + (p[1] << 8);
 			datetime->month  = p[2];
 			datetime->day    = p[3];
@@ -371,8 +376,8 @@ suunto_d9_parser_get_field (dc_parser_t *abstract, dc_field_type_t type, unsigne
 				*((unsigned int *) value) = array_uint16_le (data + 0x0B);
 			else if (parser->model == D4i || parser->model == D6i ||
 				parser->model == D9tx || parser->model == DX ||
-				parser->model == ZOOPNOVO || parser->model == VYPERNOVO ||
-				parser->model == D4F)
+				parser->model == ZOOPNOVO_A || parser->model == ZOOPNOVO_B ||
+				parser->model == VYPERNOVO || parser->model == D4F)
 				*((unsigned int *) value) = array_uint16_le (data + 0x0D);
 			else if (parser->model == HELO2)
 				*((unsigned int *) value) = array_uint16_le (data + 0x0D) * 60;
@@ -494,8 +499,8 @@ suunto_d9_parser_samples_foreach (dc_parser_t *abstract, dc_sample_callback_t ca
 	unsigned int interval_sample_offset = 0x18;
 	if (parser->model == HELO2 || parser->model == D4i ||
 		parser->model == D6i || parser->model == D9tx ||
-		parser->model == ZOOPNOVO || parser->model == VYPERNOVO ||
-		parser->model == D4F)
+		parser->model == ZOOPNOVO_A || parser->model == ZOOPNOVO_B ||
+		parser->model == VYPERNOVO || parser->model == D4F)
 		interval_sample_offset = 0x1E;
 	else if (parser->model == DX)
 		interval_sample_offset = 0x22;
